0.9.9 API documentation: closest_point.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

closest_point.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # ifndef GLM_ENABLE_EXPERIMENTAL
20 # pragma message("GLM: GLM_GTX_closest_point is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
21 # else
22 # pragma message("GLM: GLM_GTX_closest_point extension included")
23 # endif
24 #endif
25
26 namespace glm
27 {
30
33 template<typename T, qualifier Q>
34 GLM_FUNC_DECL vec<3, T, Q> closestPointOnLine(
35 vec<3, T, Q> const& point,
36 vec<3, T, Q> const& a,
37 vec<3, T, Q> const& b);
38
40 template<typename T, qualifier Q>
41 GLM_FUNC_DECL vec<2, T, Q> closestPointOnLine(
42 vec<2, T, Q> const& point,
43 vec<2, T, Q> const& a,
44 vec<2, T, Q> const& b);
45
47 }// namespace glm
48
49 #include "closest_point.inl"
glm::closestPointOnLine
GLM_FUNC_DECL vec< 2, T, Q > closestPointOnLine(vec< 2, T, Q > const &point, vec< 2, T, Q > const &a, vec< 2, T, Q > const &b)
2d lines work as well
glm
Definition: common.hpp:20